
# q-expansion of newform 80.20.c.c, downloaded from the LMFDB on 05 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 80
weight = 20
poly_data = [536802807608455434230094922445000, 3113006936793203978513537653500, 9026417197496381459207546025, 2240737884939969545921560, 111063390167690425472, -407914028595579828, 443569659980446, -14903918288, 0, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-15037203378413486634067021800804573549297205231378699542442035187440127281447540751000, -81938172292590855373162221792903625583705140670635816345873355859126878276177329900, -53533841152799470977016642642188240213080612543758482559398704235773064430157985, 23376135936081163452393108511140821725411624708684376157670155286516425476321, 8265857472465410973163392887302716974463028111250285982226876638917539391, -9901878861608758532484268744228686530901525675682558242467953420119867, 361940594997476272563579356154367540013912579711829636038467684381, 48241929004821313967895694060929908005747943302533246764169675, -233195651343600857498532355865385349085134053623433036795, -22350584455935089902198943703665141327091136351625608237], 12136640894512316918189810748693578728607242749309452155985640219799617962405875000], [[374643939742616923663858400621058223107448643383130762498240054926251911400335291776000, 2080277065432508254789146772358063275938346954921756312846321045592231342939736102400, 435551921951317612967155286295784821974688477050071837974358448816800078557311360, 54458899590745528829839998369799692890379739513877529814435572557259380875904, -115054617768878838439314067145178004319949576999350722456663499596645196416, 104977890507246864531876371404195244055941489101746946857024531954289792, -3653877190732855759459393736508392025771778642116214271203472118656, 19801345129927965435789758462316629606530144718234026507107200, -42310319678008830290070691047278630547618859707396990942080, 235280662162905617111135564870471746485304214627991894912], 10619560782698277303416084405106881387531337405645770636487435192324665717105140625], [[28128508901917110956499688585874039689208733776364871641555859079526463344688167076696521495476662729000, 182875574899646324655347666457464045056378312668443037086607475604691673405867564067984766375911072100, 54348193560615346165908456335593471820060124522841206194391935705157350944320112887304743784526065, 6512984753656182785255762728934619742061976736905216387405560113885451342362098191942617133991, -11930456639802549320409113520345908719642801559480758874563836019514592034684131655410579039, 10153235000249810644080679047066994345928337919871937570928596269119383087836182063939043, -322851611344427378779350000990867215219048699236454675198321758128246729492214296749, 5593571038388500202769266254881990300793836645749673185338078040587642817606925, -5658323792323625611598301266408242945031619305813780588212945807014351441445, 22740865108624479670523628623484330019944742770852662319494577031272945773], 6859047141319547074502303440526720209417231720612516125934730377286634453970178142195161807062500], [[991043027654474348861032424535531708168193015380252229137166980542975909582348746060523096813670346811000, 5922241354864044790154754760392842884731836859143505084519223735802116404326021951242795130535995623900, 1647320390772587201768698447684208124908634200107175413082396751591888865666099934281795782807662085, 56609884619788695510809274622977137973809098530376393285022652716877911489076065261574646179419, -375279122508872279782282529936249575203350389356500806566199070827317910249158525022416017851, 341571748119963891044483424416597892588966502324218927337862615583482536605452504370466887, -12311963859893546866571077025706709050716019616139010080210879354146230225348269312241, -262748701801378239047297224639180375966641946345825914383649761092585911826125175, -140462988577030023386594446171263115891063648900073287849615238026363499180505, 772826970456590096621565467238642865403202549459200283895635712819308907457], 13718094282639094149004606881053440418834463441225032251869460754573268907940356284390323614125000], [[2677021576453474271628499380982149713957737869959075629976680451844082117489375057915044966051076313221000, 9780231753016806354785161732710228794981968973065846564458499093313996480729944051901867411627366832900, 2656592663762160579497396224280394495191065854560974737835510748032067547110581243881457140350765935, -221985421752878940722265839719589819661239067865290838998021436489452349687605161271304323700191, -209144581956500804598399888421078952602846818636991828300151389794932080978429432831463866161, 425826827076960625183620661764600900794523301868915844461953080950062689052247365978088357, -13648844738499898763058254323148733075991398239087067570923481704337462201327583126451, -250814784046056514220019633907714342573379775338533099569940527412127180229791925, 453859668339251645643525742460006977507396497241535042529011020699209474115445, 974141384367871058206556092597564319722763092018256082592143788125557170627], 13718094282639094149004606881053440418834463441225032251869460754573268907940356284390323614125000], [[-71136338470189550079166786968186776311392261213222741193552851750953769052790942412331462508436019523000, -365662621134129124828036810197073524382107305944211183860723594649909937370864347710285344970937812700, -113623425020019611745455966456623164495686846387719330531547493847088019268218181141037800017579905, -23960493162227320197016817402928703941440476742353564476305782017080224176445403281898091344367, 27178635924507586473916614820291190569741858976973189077185685119153994125219012546564423743, -22523793695986526245001975737449454734264011525610383973389837920295804217438782312463691, 716945199293571478309252503246802965858483809272993432638625549109265184438677606013, -28800609442391812632038301659753286386005523228667827811403587617921550592978725, 13659809925036712328927225905828516694058463905442977619014615092088934104965, -50397034115556321068938653044846610828637465043902175960695933244662238701], 508077566023670153666837291890868163660535683008334527847017064984195144738531714236678652375000], [[-300519816285898029622709968280774484665311073756628424923570552539645382620003952637899016435372278570500, 3054437743510631266870585381318857593851760654274117262739050646816412003030619137214304136336695042050, 744224547821389566467537685102160296828545235142694284841225264157105101671714473912640006312514870, 197759276598959344462003566763393676783520835177707862250852988609203412679827982110709760457068, -256963145227158942716599737945283844307528275369057504629224660265232774739447176736427089622, 173234132421817657876069145809929365002185550717304421191006152827284223455559026131660564, -5793922684276457530881874283711907693309265738179642686375905039693932492046223944702, 135419541421323131599202873627916144542033087940487862667252969630850841111594900, -224893039646730522212856249344896231599348380265552219042823521223082534980610, 382202038382046699356265006306433273384538586520959375287148260764557717354], 1714761785329886768625575860131680052354307930153129031483682594321658613492544535548790451765625], [[7825295601533467416446474763062752721020827146170466294503005990697870061830494393507717905475982055329000, 16687240899905309703018148798764371688838179706520208389774240129869877094151330540468863350260378662100, 3949611899056119529059183965362537695215348292163080858311127738367065307264605055817419055466420815, 143814169849703432185035814116556065775558230392305443881968010521644633794384993585426834586641, -614698710713408338443672080712509192851087207171848547187321152689312147642208510252184175889, 774844758858592626945023836542736550456387237323882952299730042006186501953205525779437493, -25997841682023134124933082957814682394435288818596140018307895507043386201011378590099, 34474122151742112337744328946961260607914940236003107427230640014431686387395675, 196333301282453764741641410783042385905247058846234068565206769063908301086805, 1747553238996164494812027107423251741686531208361665640462792298733203498723], 6859047141319547074502303440526720209417231720612516125934730377286634453970178142195161807062500], [[-1060336215211156945574884701929888506573272208570069480532029004767568791001488504764038661548671359452000, -5830012731062792588463303504567303939400675999646188856489071425873669230379630968717030811720894114800, -1666629637145606340698091067465399902320741961832671564881836858748628283526827030108893438610996720, -68849253825776612297451366392311324349745763304330698490338394778238344751141751339507504837908, 331589858106861883198549714284688118434466975557607014220029788057164517783146360749528019732, -301385716667183471615604985935434662214568302960596522569255639260063873066597580816347384, 9713042912668022745111646790142406641725898000126816214139914826334013683648728317712, 156876038092120888257561105804812334839901931333430683022143981639585331528593100, 143272426937573912261604856158160793432217647129236935626371506093068806168660, -672344782972431632677014647597017778969797988945346096447080990769687990624], 1714761785329886768625575860131680052354307930153129031483682594321658613492544535548790451765625]]

hecke_ring_character_values = [[31, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [21, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [17, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [290267, 11, 2, -1, 0, 0, 0, 0, 0, 0], [0, 54, 426, -8, 1, 0, 0, 0, 0, 0], [296522588, -102, 242, -526, 3, 18, -13, -1, 1, 3], [0, -136590, 421887, -3773, -24, -80, -50, -75, -50, 5], [0, 5006476, -3333701, -28872, 2255, 109, 258, 387, 258, 278], [419698783620, -6440, 15517, -33352, 481, 1906, -481, -911, 911, 481], [0, 6861008, 30423957, -298944, -58571, -11446, -4812, -7218, -4812, 4228], [21936062041830, -155436, 607980, -1289910, -86214, -250344, -38490, 105840, -105840, -86214], [66712158666368, -3340894, 8761931, -18801218, -71008, 544172, 167686, -27328, 27328, -71008], [0, -12272710794, -5413741815, -35202923, 4788803, 156773, 152516, 228774, 152516, 72001], [358734540819442, 9469356, -17715908, 40531324, -528310, -620165, 4607657, -1657966, 1657966, -528310], [0, 16248990255, 13340510028, 60376808, 11500178, -3336564, -5801688, -8702532, -5801688, -5365968], [0, -32936483414, -2953677323, 792984984, 1167227, 4568350, -3880500, -5820750, -3880500, -10389100], [0, 29946275062, -24421675381, -852841707, -66066040, -35718776, -26873262, -40309893, -26873262, -4591117], [33269827980189740, -7241304, -133889473, 265508312, 51359675, 230597830, 75905061, -52402821, 52402821, 51359675], [53340756501165662, 1060748144, -2628952369, 5673568459, -17234371, -284306071, -31967378, 31626932, -31626932, -17234371], [0, 2801733069615, 1223927275128, 19033123464, 16994702, 187307140, 1445080, 2167620, 1445080, -185139520], [-197582715850453272, -246472734, -373625979, 409732830, 64458122, 712515232, 151272940, 333758602, -333758602, 64458122], [0, 2657171218872, 10681856307363, 31450467174, -3802728563, -232957225, -292669390, -439004085, -292669390, -206046860], [230377153173269040, -2483390502, 3755320083, -8973688194, 295838916, -1534007004, -3544457622, 486980796, -486980796, 295838916], [0, -11644980056889, 8733971486792, -333719112, -2536416858, -1918217268, -2069606136, -3104409204, -2069606136, -1186191936], [-1107619950363170710, -8860967376, 35063575682, -72040199698, -2491120618, -9148898288, -1272611754, -227777076, 227777076, -2491120618], [0, -66318788568324, -60365011602687, 696388702124, 16181674579, 6332784433, -2030003534, -3045005301, -2030003534, -9377789734], [-3894411611743085698, -21468403212, 57330182096, -122021517994, 142728070, 3865213160, 778291618, -2186407208, 2186407208, 142728070], [0, -194908437369720, -25702770157161, -738783660368, -7540644791, -10048282218, -2758646196, -4137969294, -2758646196, 5910312924], [0, -19529712224079, 307441607881296, -82549642560, 150224739180, 17067320880, 7470009120, 11205013680, 7470009120, -5862307200], [-5352673574340711730, 29258289720, -57097897839, 137030731965, 7019191623, -24606762087, -24970518480, -25571892288, 25571892288, 7019191623], [0, -3536623374808, 255835195075180, -2918493242148, -24244395788, 2963828684, 39973365648, 59960048472, 39973365648, 56996219788], [0, 300861414192996, 2583425444075778, -3248385209072, -134614789469, 22244459508, 77385764376, 116078646564, 77385764376, 93834187056], [-1425372897223022412, -565480367436, 1446684786819, -3099296212932, 11522608013, 247817164018, 127173943399, -45298454147, 45298454147, 11522608013], [0, 1315494213529092, -4526843209379052, -24224354069262, 1090132109310, -321540913206, -206028267432, -309042401148, -206028267432, 12498512058], [-59197138865968997540, 2099877929074, -4926216396674, 10830064047026, 45151726939, -609240818126, -141146970397, -274618530353, 274618530353, 45151726939], [-172489340007883439930, -6406534481712, 16919362330327, -36109000104485, 23811678933, 188370874773, -774586593230, -511042260356, 511042260356, 23811678933], [-142185402341044792552, 13323788314940, -37341680424160, 79323952340980, 578598953030, -228605572780, -218209879970, 569607435830, -569607435830, 578598953030], [0, -3534370338173214, -22641197924592699, 37068015446531, -3338361722075, -57159530837, -190041559604, -285062339406, -190041559604, -227902808569], [0, 325415872839189, -15761856184042794, 17401075863696, -9769694673704, -1162699164028, -690076401976, -1035114602964, -690076401976, 127584561064], [0, 12940522867620172, 30727357504842179, -15221530463904, 4069527064133, 861725734390, 835357480620, 1253036220930, 835357480620, 391310486540], [0, 15186277715025970, 11353235473842139, 18325278637335, -5323259868475, -126189016685, 131734872420, 197602308630, 131734872420, 323791325315], [-206377791620300276860, 21780592375458, -73865160969640, 153545030501738, 3251750690637, 5075433081942, -4187071698511, 1577463288905, -1577463288905, 3251750690637], [-1977171058431383583058, 32297035683892, -82546773605828, 177600562567130, 143840445274, -7669395631736, -2190575054890, 542491084864, -542491084864, 143840445274], [2638233245889826299648, 28980511143468, -72997409713758, 155891228401476, -1702173252112, -7080115234712, 1561446105748, 4528499057824, -4528499057824, -1702173252112], [0, 70923060907878036, -71629753814495553, -669016047156964, -12284006537387, -5777957285945, 2013549695950, 3020324543925, 2013549695950, 8798281829870], [0, -122090453027394330, 77298179254184689, -644199963310431, -15220814915526, -3175343860962, 5133404268486, 7700106402729, 5133404268486, 10875450263691], [-317492089488737538840, -159233182494710, 434395395516241, -929836456105210, -9162359842982, -461305134992, -1290718204780, 4749679967722, -4749679967722, -9162359842982], [-2516236863244001305212, 201642273177652, -529744706341337, 1141832691771980, 10420085374897, -17375455030598, -6058763428765, -13230701738639, 13230701738639, 10420085374897], [0, -185707164020965896, -74344565006504634, -1113478970377344, -70811355178033, 3228880867396, 23538532644952, 35307798967428, 23538532644952, 32078918100032], [0, -84342845225747315, -560527137714403242, -2404132973552496, 48440645360000, -32883289175228, -16027730694456, -24041596041684, -16027730694456, 8841693133544], [3701775817819732063870, 373388931637556, -1035147907764640, 2202653280113206, 15005072811254, -43278575336296, -36280151537342, 13325107307240, -13325107307240, 15005072811254], [0, -94709119308939960, -499614132868329517, -1818869589084114, -57519250150035, -2123281323177, 24097375602306, 36146063403459, 24097375602306, 38269344726636], [-13771802636656017312560, 235246557463242, -531491442944501, 1151259450389446, -25343937443260, -159313160691740, -43994781515782, 35047368251348, -35047368251348, -25343937443260], [10259519554942749367402, -7236949558620, -38781210107064, 74600726114892, 18883512139218, -5043990361017, -63231135724779, -18771988346238, 18771988346238, 18883512139218], [20063439295547165371788, 242069512565838, -458449049696700, 1003005705723606, -60819575790553, -171458881425038, 45120150198283, 78686573617435, -78686573617435, -60819575790553], [0, -1253881743286358408, 632199217323759410, -9005061933913584, -230174632583908, -51883100810324, 64356720597912, 96535080896868, 64356720597912, 148418181707192], [0, 1514019807302633954, 452054953798447824, -1979847932249352, 730728028535881, -6200918203252, -52686209017224, -79029313525836, -52686209017224, -72828395322584], [42497966925424218724110, 3923938923085968, -10620505962830073, 22774114709971203, 229694235123573, -152281135635567, -105206436286866, -168906260251356, 168906260251356, 229694235123573], [60636591534855315211568, 2384382369193702, -6373368175980011, 13690367814208274, 126224656077220, 84683772531820, 169390964233262, -109355513695172, 109355513695172, 126224656077220], [0, 1922988633629002110, -2915959393749733323, 8947387148737521, -409005146407201, -117567407755991, -208009227793532, -312013841690298, -208009227793532, -194446433934307], [-80451905270701932987678, 609013803658284, -1327706982294678, 2911953277533942, -50571629526708, 55835060521347, 346597765141491, 29015310391254, -29015310391254, -50571629526708], [0, -148798469924787495, -4024033238395552182, -20860415926856512, 28322353942792, -97030913819948, 124440385635784, 186660578453676, 124440385635784, 283691492273624], [0, 520763207502105726, 2369592785765176215, 11268086466416733, -2413216377039903, -74403539407713, 4375204572024, 6562806858036, 4375204572024, 80966346265749], [0, -266664929021726565, 9629786811432425316, 5265673026355736, 790741650745482, 453932854373156, 411268745825912, 616903118738868, 411268745825912, 162970264365712], [64194026090801110886328, -1231490737448052, 4502637190802424, -9447372514193268, -418527713070986, -601113339556876, 475502535354206, 334364109086318, -334364109086318, -418527713070986], [0, 2914816484375200428, -3843093690043794456, 9258482541817742, 1943760475549750, 793237161227506, 665436973803712, 998155460705568, 665436973803712, 204918299478062], [0, -6403657753487596822, -4453201136137794225, 31111937776805895, 360046109596294, 291655060406786, -46220297446518, -69330446169777, -46220297446518, -360985506576563], [-514533951785295135909892, 630177621028596, -1015754288507379, 2800461492953748, 387749931453687, 582907610948262, 234869164162989, -1249219710666273, 1249219710666273, 387749931453687], [0, -8878867420787043816, -15489648953851223196, -32549077086800740, 2489577763971194, -603813733587834, -579653328473868, -869479992710802, -579653328473868, -265666259122968], [0, -19105591317148184393, 3297545442325463090, 130914676244161800, -2944056739943962, -187253574229928, -1481278835909856, -2221918253864784, -1481278835909856, -2034664679634856], [805013624321271388767590, 8641352965401364, -24286045905007856, 51621514775488550, 441867585292918, 1694482691400328, 1554326234351570, 236662782519928, -236662782519928, 441867585292918], [0, -5444742676214164040, -27043509613280344874, 103050367237601328, -6427471358413822, 2188134041121526, 2032131109534812, 3048196664302218, 2032131109534812, 860062623180692], [162736823784580257089640, -4056994877123820, 5711334033561312, -13850888676340428, 582136988229106, 4297169684407196, 665462866470746, 760234109051354, -760234109051354, 582136988229106], [0, -32906213302445694300, -4339241593294642896, 19494401412964768, 6379388248130743, -1666504983807384, -2832509014387968, -4248763521581952, -2832509014387968, -2582258537774568], [0, -22940477891596662834, -15588757820295042147, 260147806755018745, -13460708609376309, 293239197372349, -1429923983048612, -2144885974572918, -1429923983048612, -2438125171945267], [185075180966631824390540, -37101965085539098, 115026379597407056, -242129899988629226, -4353105360741409, -4971009755623534, 4352773630026907, -252970039926133, 252970039926133, -4353105360741409], [0, 51835177166556427436, -3801234943013605480, 173128246012044960, 5189245284578743, 8793061476978392, 8082375717428064, 12123563576142096, 8082375717428064, 3330502099163704], [-1103719456850911084857130, -18112860631883760, 68111960136406583, -141675569396928325, -5617163820412011, -13386083415918291, 2234162757125450, 2628005272681436, -2628005272681436, -5617163820412011], [0, -75654826532730081054, 7644761274704323083, 473038192861128539, 10896585982619858, 10000900553875254, 5495694459965658, 8243541689948487, 5495694459965658, -1757358863926767], [-106397727279734573120878, -88431082164923136, 239187930127521878, -514373760894365374, -6731705764351750, -8211304224641840, -6536360395707702, 7774152053272356, -7774152053272356, -6731705764351750], [-2224182750243492473716670, -80421686961753508, 231867381320617712, -490213510336910960, -3948913428715906, 6972775916027939, 10321748261859445, -5534298386327206, 5534298386327206, -3948913428715906], [1448721993980723613537460, -84247040246191242, 206874621339862330, -446229876787423538, 2601195303847057, 2019007803659702, -21009743502749559, -4631498621809755, 4631498621809755, 2601195303847057], [3851704796542398110504182, -223369978481389648, 596265371327633051, -1274785371259355849, -4731960831979519, 9357736378956701, -11662559770094522, -7090310482130668, 7090310482130668, -4731960831979519], [-491499318808807542267952, -81512549250997098, 196984180691964749, -432073875374531398, -3845929510605180, 37387539564801900, 25288825859480606, 13013419994276948, -13013419994276948, -3845929510605180], [0, 69844749445746832788, 177134212275314127237, -310437304791171256, -33479416905248771, -16461634311197177, -13067551976843834, -19601327965265751, -13067551976843834, -3139693654068574], [2074718491663482172749240, 64718422367590644, -85130920567500924, 209125629992173908, -11136800772563226, -57897509432010876, 5758470572711334, -10490565744329778, 10490565744329778, -11136800772563226], [0, -176782876957192877491, -9919843505279255936, 159386129207661648, 18877692600055168, 8195968744023896, 6243007141828752, 9364510712743128, 6243007141828752, 1168541968719232], [-8352391277173681068818790, 62172653902841796, -232085207356279824, 477070977139741380, 12252858495330682, -962550611251633, -41244594161948635, 7694640061260962, -7694640061260962, 12252858495330682], [0, -224240250213829699764, 62430316458905725506, 175832859073696026, -9138496130656792, -24336888446873960, -30519583626391340, -45779375439587010, -30519583626391340, -21442486992713050], [-771062574579959743247178, 315327146668090164, -932593777990162296, 1968266812704941406, 22479079392624238, -3214132103363032, -38321410204443382, 15940257178407848, -15940257178407848, 22479079392624238], [0, -13332889023180238038, 189767649856345272795, -2049811208871552696, -38703060957583017, -37735292184482766, -17863150859292492, -26794726288938738, -17863150859292492, 10940565895544028], [0, 141115808318625670737, 510087432608329275948, 566741711020429392, -133039638989250600, -1362042994337424, 4178771607916032, 6268157411874048, 4178771607916032, 7630200406211472], [17830318323269730013460320, -221418572849008776, 636998366568844612, -1351632768967207088, -15671318915345728, -41480646589481168, -24175213333131544, -2547669934797016, 2547669934797016, -15671318915345728], [0, -215626289949045369774, 317961088496265726696, -3903556013130103240, 87840135909096153, -30871817433195748, 246055324423064, 369082986634596, 246055324423064, 31240900419830344], [-14402353010746893031261092, 823588392832338840, -2133023526014310405, 4590346979505690528, 18978148360192415, -103994411196714290, -3058417251978191, -10419098933749385, 10419098933749385, 18978148360192415], [-2419722018031704956420220, 546551231384589782, -1711698274972292050, 3584285381484166462, 50960442154435253, 36787376069001278, -83759252136391259, 45258992869320665, -45258992869320665, 50960442154435253], [0, 683392721646622200808, -86990418595063294069, -2703337308231732528, 16224892003301609, -63554544579977138, -46462923035465796, -69694384553198694, -46462923035465796, -6139839973221556], [-8359550888857152871764090, 169004268756230724, -383190368709430284, 833734297593000426, -13382486980773766, 76940505483100984, 150557957072198518, 13796065861361152, -13796065861361152, -13382486980773766], [3125165780092501523831642, 508605604746951456, -1258118188966336408, 2735687681873650136, 13322572413204520, -117762068876440720, -34663249110401672, -40004342483532416, 40004342483532416, 13322572413204520], [0, -627058710142961170299, 626906821837333031910, -510265712358125360, -379991015435574812, -3506278092734508, 37298797570655784, 55948196355983676, 37298797570655784, 59454474448718184], [26657561746669756798364902, -282991037057247308, 1064593418057921188, -2218469044865437006, -92467268390151758, -176840792710092248, 75848413146652622, 52610258267977936, -52610258267977936, -92467268390151758], [0, 472366449137812375833, -3003493437791806869138, 1509941692124284432, -229598590482569036, 27465154726433892, 36909449924666184, 55364174886999276, 36909449924666184, 27899020160565384], [0, -242297982729852114934, 567324393931253765101, 6590377079655747591, -722955847040419703, 144548837675678711, 164699414938742892, 247049122408114338, 164699414938742892, 102500284732435627], [0, 1402232168242646153357, 816549842782590496442, 15761013805451075232, -73126651982430152, 58050688272195428, -107564674825210584, -161347012237815876, -107564674825210584, -219397700510011304], [-49249627033605371169720670, -983345479941892500, 2592377401288589360, -5494201474057276456, 48541566740557590, 153427228524663075, -77011207023175843, -188360767568323030, 188360767568323030, 48541566740557590], [-18170209476524497114551412, 3329827164496800002, -9092228463046102486, 19435202389846472122, 165680848329753215, -153104013794444230, -92428328610281009, -30371844922331797, 30371844922331797, 165680848329753215], [0, 3345339086105013550584, 2595295209504295750194, 6571932555703826200, 918277297841345822, 196799306299481258, 74294474975578676, 111441712463368014, 74294474975578676, -85357593836113244], [0, -310323261344885006401, 1585393643519142757714, 17406723988134003384, -312374547216868514, -109183962137516704, -305890943983196208, -458836415974794312, -305890943983196208, -349652453837277608], [0, 556297676829258966192, 1035177233918004149526, 4696996896358304436, 197474898310388916, -2115234664399788, -75960997114322736, -113941495671484104, -75960997114322736, -111826261007084316], [-18199652550819543283447560, 746476333572089250, -2703258259189028511, 5640225593949164550, 206931966355459382, 127100811311037592, -430908431517893600, -98796203259245762, 98796203259245762, 206931966355459382], [-54172073366622839329644958, -7145600783378185636, 19581454863541047542, -41859422486216807102, -392787019235680888, 37319083277963027, 2196723264784879, 123241095541410494, -123241095541410494, -392787019235680888], [0, 6230106147463659199914, 2340672211806217173657, -19276619712655517224, -661477733151002437, -291134123538768570, -63372785340697380, -95059178011046070, -63372785340697380, 196074945527722500], [0, -2303837582560908454578, 667864363363420963203, 46229662814795727129, 500249288049303766, 309838554051482186, -214248959671198738, -321373439506798107, -214248959671198738, -631211993558280293], [0, -298405539305031667416, 2750147483974720358579, -4068259275723229530, 719060764115243319, -313860015012616179, -397798928461967058, -596698392692950587, -397798928461967058, -282838377680334408], [-239136837774190356178547620, -2289465660067640272, 6821626212855663239, -14407249780280206976, -197333010386436841, -124801088426041426, 211690023330641857, -55648505377189177, 55648505377189177, -197333010386436841], [136381310442760573032445048, -3926493513220927644, 9778040735243927508, -21085914212650546164, 58025086075774878, -94182009248582412, -999203085952519362, -125966191285241394, 125966191285241394, 58025086075774878], [-69362741677586498284221158, 1179671351267263428, -2214502940580479324, 5022577483434397648, -109666188344189050, -43633782502249265, 683569801805815409, -93172247933366998, 93172247933366998, -109666188344189050], [0, 2531710480173098803443, -8263479129676318250526, 43457943214689758584, 2477538615691425678, 616269411486661984, 2309909273742928, 3464863910614392, 2309909273742928, -612804547576047592], [0, -3777933906037865748530, 2358261507039817131920, 33992090057248670472, -132949937213940763, 560624132097227524, 290243216917863048, 435364825376794572, 290243216917863048, -125259306720432952], [0, -6307837807179393307014, 11081271716349994158973, -12855093221072989365, 897093288572077518, -432514610082511518, -454627578081898446, -681941367122847669, -454627578081898446, -249426757040336151], [357505457725660969748889380, -3479852154533068026, 9367457966310116006, -20091236459962593178, -183031043913741931, 1120173499257157054, 1020789979386257301, 123663819795631857, -123663819795631857, -183031043913741931], [81384663206897519729459942, 14334071824801943336, -39411236448369144319, 84298531431234081421, 905829856093668047, 662672996558090717, 468570866004162508, -476546197052027128, 476546197052027128, 905829856093668047], [0, 3255517983721362476556, 2854586848832292516933, -7510746584737713140, 399399805675476351, 476680313108501269, 624720706310053018, 937081059465079527, 624720706310053018, 460400746356578258], [0, 9973818179491696840838, 395282672434505064909, 74270657766380708481, -3265039035368570384, -395023620788739208, -1039038344148213846, -1558557516222320769, -1039038344148213846, -1163533895433581561], [0, -4979018873392484674717, 464089520509406429382, -27868082266931986344, -3812276983462814174, -753845345447330488, -225494414578251936, -338241621867377904, -225494414578251936, 415603723579952584], [117223276875180961961491748, -13013179620416253352, 30649708665419188853, -66889987950663312728, 199637048919999641, 2716172345023291106, -999106421364536729, 442527570510723161, -442527570510723161, 199637048919999641], [870792828827498961507191422, 7130290477717904904, -16426600798001583071, 35568332113978926997, -618581435554838737, -1908682399205029967, 1190472438854532416, 846890890740507248, -846890890740507248, -618581435554838737], [577299380757340492374830430, 11369136156123176868, -30914014849439452764, 65979496582472238234, 390183065426127930, 1682687728035587880, 2257715657840588742, 270129566000435472, -270129566000435472, 390183065426127930], [850816485697926695644337200, 34025706054855942210, -93602814799603001777, 200063958719042324566, 2010679551814320004, -1178558130468830956, -1408059977748677022, -757424048304226884, 757424048304226884, 2010679551814320004], [0, -8970457872144600509910, 8267252002019610531720, -135387728121233225448, 999190607631607257, -3479456531847100596, -2701635316024222152, -4052452974036333228, -2701635316024222152, -572996442189232632], [0, 10182993532308780108378, 2206539950127623731935, 75235257892976851691, -7918257161249413969, 750200953730546217, 764695878728242344, 1147043818092363516, 764695878728242344, 396842864361817299], [-231072433618442323823052620, 39397085759254509482, -107939321701135109488, 230120150023540004290, 1462949453852924729, -1198061865408909346, 269403348307193725, 1065930016867106069, -1065930016867106069, 1462949453852924729], [0, -1778917942515487537418, 8152464543083923319744, -151696599085206101400, -3561078736239757603, -2944843313518255052, -1440159442307088984, -2160239163460633476, -1440159442307088984, 784604150057621576], [306885190657024763189292208, 23350424542911748516, -60536545207778753270, 130658066393012103044, 992168128266346324, -5543373455400359456, -3523384717897185928, -1400178395416174820, 1400178395416174820, 992168128266346324], [0, -29377795880323007709186, 28063684681876496281449, -226264994787975585695, -3024477805275872623, -3584257278296756377, -1388510905665302224, -2082766358497953336, -1388510905665302224, 1501490919798803041], [717478140254717569706575242, 6374345726103096744, -7242610464832593174, 18481279857032988426, -1290728353556645806, -6067678774887514496, 1007802946905126778, -1119806041320959828, 1119806041320959828, -1290728353556645806], [-334228854399453116043644670, 36341166101301056152, -103410903370968368516, 219049323061651887128, 1620495905010495640, -3008249881263457760, -3680104537108429936, 2227754296331624968, -2227754296331624968, 1620495905010495640], [0, 26079023224529659671102, -12057381510209063453709, -224981321750824822119, -6264993875735318256, -4900552251720858576, -2686030516614515382, -4029045774921773073, -2686030516614515382, 871506476799085503], [0, -75281115247862173826241, -2168328807935995801884, 195930123022339141592, -2590348582697617274, 1503170337732037780, -238371807887231720, -357557711830847580, -238371807887231720, -1860728049562885360], [0, 1161391408635408697682, -12922732791658219870479, -23410759591688496585, 2196503715512783920, 6127705580025046880, 7450203562692000630, 11175305344038000945, 7450203562692000630, 5047599764012954065], [-1525820301148330001949923910, 38781866164732531488, -112469419358468691240, 239136921784845647592, 3710847540007179192, 12744135974068417392, 7615082056347056136, -1519741876699266720, 1519741876699266720, 3710847540007179192], [276849391740790352821789628, -62444452246196907178, 164789437728882202940, -354440438066465070962, -2763637604709869677, 9778948977470777018, 5735929062065134999, 2569940455079706695, -2569940455079706695, -2763637604709869677], [1891493219252692308050871302, -27987544495018986504, 50304469417720960589, -113068708432088518663, 5149517497009943131, 12851491059641632061, -9880906061910665144, -3041597832611604992, 3041597832611604992, 5149517497009943131], [0, 102993552152506954157508, 13616881540444847380971, -244313679357330981568, 10221744268301872773, -1316466725171770762, 315130438809632876, 472695658214449314, 315130438809632876, 1789162383386220076], [0, -51444927655087445047357, -9013683718717392672502, 439467338901443526216, 28734860077893652906, 7061766638691521432, 678546716498642784, 1017820074747964176, 678546716498642784, -6043946563943557256], [-983232423451438567741103010, 105448626182356582976, -272543758174942779697, 585984300059151661747, 1548878946709850933, -1912362349283051527, 12820503695490004486, 588898992751033796, -588898992751033796, 1548878946709850933], [1431208680746019381049478600, 82374611806120986540, -260996528188765405468, 544882972586356071188, 7175634542684163746, 7112801947157658796, -11352417337834814286, 9590912980021060194, -9590912980021060194, 7175634542684163746], [0, -14169367300746806706018, 133082472561216134741181, -175899491156152213699, 29603750124326604080, -1672447163504838552, -2727398452391333214, -4091097678586999821, -2727398452391333214, -2418650515082161269], [0, -9989491485367242652668, -147661822396574945511666, 851660107284666742782, -26323123737498721788, 2802214220564580444, -4122187750485674652, -6183281625728511978, -4122187750485674652, -8985495846293092422], [-190768232604523252907985460, -206883249900250239456, 570406840293684879939, -1214858194983561500616, -8056476776677143717, 5868361412206332918, 272855847398856237, -6458165829836781357, 6458165829836781357, -8056476776677143717], [0, 97189099640196872207902, 61980961124744957438387, -687950484056369691048, 4782224872051523603, -11511300139918232582, -6268669348907841564, -9403004023361762346, -6268669348907841564, 2108296116556470236], [0, 86894150041978515646362, 31518350057985455635401, -132660111325047735185, 21112668328306713307, -10751052375358864107, -13375434268577414904, -20063151402866122356, -13375434268577414904, -9312099027507258249], [355023020528123793077583882, -20750152606527395628, 40432335979724215650, -90688418027129628126, 2121365151008937168, 6985052894713822023, -5560653113045453373, 418109890774793790, -418109890774793790, 2121365151008937168], [0, -42258324516137479778655, -128916746748076005350616, 1524377844513291105872, 1249700869297104384, 13282624270968909992, -1944621655647604816, -2916932483471407224, -1944621655647604816, -16199556754440317216], [0, -25556888590212313423770, 158523619418797717437456, -381460229490003096984, 42680274470393668197, 8247597221180199156, 10403749093665663912, 15605623640498495868, 10403749093665663912, 7358026419318296712], [0, -143011818529241289468831, 112306819562188467365574, 1814872925564742021264, 1699381030694594136, 15904704572839840836, -2225536874944972728, -3338305312417459092, -2225536874944972728, -19243009885257299928], [7553488613865487205614344048, 348303265261105237002, -889798354552633021533, 1916948023224018318198, 4157850482523510044, -42732587261063638316, 11827858362667119394, -874530506373810596, 874530506373810596, 4157850482523510044], [-7989070282390351867728221640, 52521995231115003266, -106966608386758709743, 234992634922485587734, -8056548723096080650, -21603819527531666920, 13137719096675798272, 7972181962225802414, -7972181962225802414, -8056548723096080650], [7589643752944453191885946170, -183086942187685983756, 478966060033524199368, -1027499361156144654396, -3007861759238482390, 19840884393096252175, -2862871052087980283, -3104697884058414014, 3104697884058414014, -3007861759238482390], [0, -130045745342515704885312, -245694757667402995731123, 518209479730988495598, -54496987060336987511, 12193343182559502755, 13727260404155978810, 20590890606233968215, 13727260404155978810, 8397547423674465460], [2593297873035467380606320022, -31905763869692217756, 88448450132430390964, -185581892858263667702, 1635667574460052618, -7807282586944240312, -13659020811630839946, -8431189165250054832, 8431189165250054832, 1635667574460052618], [0, -18723286831300218080465, -418620819827450175169042, 552314670811585359624, 53484997497757211738, 18764374931065367104, 11140771545100465008, 16711157317650697512, 11140771545100465008, -2053217613414669592], [0, -180273729166643631202732, -256605079273436059359738, -1130847328398701026746, 69091203383437222624, 1785540147287746688, 8912612122828551516, 13368918184242827274, 8912612122828551516, 11583378036955080586], [0, -206531678990991070277556, -288801239967785863665795, -2087961821179187188112, -14826847168019863735, -17009087009671927006, 5317434345346638788, 7976151518019958182, 5317434345346638788, 24985238527691885188], [7874089701697630774956505788, -206286181821243695520, 609734912626595545983, -1284338346347211746184, -11733206430632297961, 51182844667981139694, 68653163108265059793, -17676712960162408689, 17676712960162408689, -11733206430632297961], [0, 506768582326079255029348, 469657151325565600814693, -1432819089881340230448, 171364068860013088949, 4711291877824601647, 6399644472715432614, 9599466709073148921, 6399644472715432614, 4888174831248547274], [0, -484664405799461132681046, -36023977737213725504990, -4702340868932212593048, -7990093598714583795, -30777283444038877224, 18669022491063449232, 28003533736595173848, 18669022491063449232, 58780817180634051072], [7135402619054728270403340128, 531616922804864159880, -1522061356812789505404, 3227054829675081893112, 31323402075273277848, -22267822610981622432, -49534181705752332864, 18201019712131358232, -18201019712131358232, 31323402075273277848], [0, 179030674941876668332110, 350438419760112334633467, 2330491598349327117841, -56644234237275040584, 27925293332504771272, 11683830278325902314, 17525745417488853471, 11683830278325902314, -10399547915015917801]]
